package org.jboss.as.integration.hornetq.deployers.pojo;

import org.hornetq.jms.server.config.ConnectionFactoryConfiguration;
import org.jboss.logging.Logger;

import javax.management.ObjectName;

public class HornetQConnectionFactoryDeployment extends HornetQJMSDeployment<ConnectionFactoryConfiguration>
{
   private static final Logger log = Logger.getLogger(HornetQConnectionFactoryDeployment.class);

   @Override
   public void start() throws Exception
   {
      log.info("Deploying ConnectionFactory " + config.getName());
      try
      {
         jmsServer.createConnectionFactory(false, config, config.getBindings());
         
         // Register the Control MBean in MC
         registerControlReference(new ObjectName("org.hornetq:module=JMS,name=\"" + config.getName() + "\",type=ConnectionFactory"));
         
      } catch (Exception e)
      {
         log.warn("Error deploying ConnectionFactory: " + config.getName(), e);
         throw e;
      }
   }

   @Override
   public void stop() throws Exception
   {
      log.info("Destroying ConnectionFactory " + config.getName());
      try
      {
         unregisterControlReference(new ObjectName("org.hornetq:module=JMS,name=\"" + config.getName() + "\",type=ConnectionFactory"));
         
         jmsServer.destroyConnectionFactory(config.getName());
      } 
      catch (Exception e)
      {
         log.warn("Error destroying ConnectionFactory: " + config.getName(), e);
      }
   }

}
